@@ -16,7 +16,7 @@ use Test::BDD::Cucumber::Definitions::TypeConstraints qw(:all);
 use Test::More;
 use Try::Tiny;
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 our @EXPORT_OK = qw(
     request_send
@@ -85,17 +85,13 @@ my $validator_request_send = validation_for(
         { type => ValueString },
 
         # http request url
-        { type => ValueString },
+        { type => ValueUrl },
     ]
 );
 
 sub request_send {
     my ( $method, $url ) = $validator_request_send->(@_);
 
-    if ( $ENV{BDD_HTTP_HOST} ) {
-        $url =~ s/\$BDD_HTTP_HOST/$ENV{BDD_HTTP_HOST}/x;
-    }
-
     my $options = {
         headers => S->{http}->{request}->{headers},
         content => S->{http}->{request}->{content},
