@@ -16,7 +16,7 @@ Test::BDD::Cucumber::Definitions::HTTP::Ru - Шаги на русском язы
 
 =cut
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 ## no critic [RegularExpressions::ProhibitCaptureWithoutTest]
 ## no critic [RegularExpressions::RequireExtendedFormatting]
@@ -88,9 +88,10 @@ When qr/тело HTTP-запроса заполнено данными/, sub {
 
 =pod
 
-Отправить запрос любым HTTP-методом на любой URL:
+Отправить запрос любым HTTP-методом на любой URL (внутри URL можно использовать
+переменные окружения):
 
-    When HTTP-запрос "GET" отправлен на "http://metacpan.org"
+    When HTTP-запрос "GET" отправлен на "http://${TEST_HOST}/index.html"
 
 =cut
 
