@@ -16,7 +16,7 @@ Test::BDD::Cucumber::Definitions::JSON::Ru - Шаги на русском язы
 
 =cut
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 ## no critic [RegularExpressions::ProhibitCaptureWithoutTest]
 ## no critic [RegularExpressions::RequireExtendedFormatting]
@@ -58,7 +58,8 @@ our $VERSION = '0.16';
 
 =pod
 
-Прочитать данные из HTTP-ответа в структуру:
+Прочитать данные из L<HTTP-ответа|Test::BDD::Cucumber::Definitions::HTTP::Ru>
+в L<структуру|Test::BDD::Cucumber::Definitions::Struct::Ru>:
 
     When содержимое HTTP-ответа декодировано как JSON
 
