@@ -9,6 +9,7 @@ use MooseX::Types (
             ValueString
             ValueInteger
             ValueRegexp
+            ValueUrl
             ValueJsonpath
             )
     ]
@@ -18,7 +19,7 @@ use MooseX::Types::Moose qw(Str Int RegexpRef);
 
 use Try::Tiny;
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 subtype(
     ValueString,
@@ -59,6 +60,31 @@ coerce(
     }
 );
 
+subtype(
+    ValueUrl,
+    as Str,
+    message {
+        "$_ is not a valid URL"
+    }
+);
+
+coerce(
+    ValueUrl,
+    from Str,
+    via {
+        my $value = $_;
+
+        try {
+            $value =~ s/\$\{ (.+?) \}/$ENV{$1} || ''/gxe;
+
+            return $value;
+        }
+        catch {
+            return $value;
+        }
+    }
+);
+
 subtype(
     ValueJsonpath,
     as Str,
